@@ -4,8 +4,8 @@
 #' representing predictions on a regular grid. The core products are occurrence,
 #' count, relative abundance, and proportion of population. This function loads
 #' one of the available data products into R as a
-#' [SpatRaster][terra::SpatRaster] object. Note that data must be download using
-#' [ebirdst_download_status()] prior to loading it using this function.
+#' [SpatRaster][terra::SpatRaster] object. Note that data must be downloaded
+#' using [ebirdst_download_status()] prior to loading it using this function.
 #'
 #' @param species character; the species to load data for, given as a scientific
 #'   name, common name or six-letter species code (e.g. "woothr"). The full list
@@ -73,7 +73,7 @@
 #' @examples
 #' \dontrun{
 #' # download example data if hasn't already been downloaded
-#' ebirdst_download("yebsap-example")
+#' ebirdst_download_status("yebsap-example")
 #'
 #' # weekly relative abundance
 #' # note that only 27 km data are available for the example data
@@ -112,6 +112,7 @@ load_raster <- function(species,
 
   species_code <- get_species(species)
   species_path <- get_species_path(species, path = path,
+                                   dataset = "status",
                                    check_downloaded = FALSE)
   if (!dir.exists(species_path)) {
     stop("No data found for the requested species. Ensure that the data were ",
@@ -194,7 +195,7 @@ load_raster <- function(species,
 #' Load the relative abundance trend estimates for a single species or a set of
 #' species. Trends are estimated on a 27 km by 27 km grid for a single season
 #' per species (breeding, non-breeding, or resident).  Note that data must be
-#' download using [ebirdst_download_trends()] prior to loading it using this
+#' downloaded using [ebirdst_download_trends()] prior to loading it using this
 #' function.
 #'
 #' The trends in relative abundance are estimated using a double machine
@@ -225,7 +226,7 @@ load_raster <- function(species,
 #'   - `species_code`: the alphanumeric eBird species code uniquely identifying
 #'   the species.
 #'   - `season`:  season that the trend was estimated for: breeding,
-#'   nonbreeding, or resident.
+#'   non-breeding, or resident.
 #'   - `start_year/end_year`: the start and end years of the trend time period.
 #'   - `start_date/end_date`: the start and end dates (`MM-DD` format) of the
 #'   season for which the trend was estimated.
@@ -250,7 +251,7 @@ load_raster <- function(species,
 #'   - `species_code`: the alphanumeric eBird species code uniquely identifying
 #'   the species.
 #'   - `season`:  season that the trend was estimated for: breeding,
-#'   nonbreeding, or resident.
+#'   non-breeding, or resident.
 #'   - `srd_id`: unique integer identifier for the grid cell.
 #'   - `abd`: relative abundance estimate for the middle of the trend time
 #'   period (e.g. 2014 for a 2007-2021 trend).
@@ -275,7 +276,7 @@ load_trends <- function(species,
   stopifnot(is.character(species), !is.na(species), dir.exists(path))
   stopifnot(is_flag(fold_estimates))
 
-  v <- ebirdst_version()[["version_year"]]
+  v <- ebirdst_version()[["trends_version_year"]]
 
   # trends species and seaons
   species_code <- get_species(species)
@@ -292,6 +293,7 @@ load_trends <- function(species,
   for (i in seq_along(species_code)) {
     p <- get_species_path(species_code[i],
                           path = path,
+                          dataset = "trends",
                           check_downloaded = FALSE)
     if (fold_estimates) {
       f <- stringr::str_glue("{species_code[i]}_{season[i]}_ebird-trends_",
@@ -311,7 +313,113 @@ load_trends <- function(species,
   }
 
   # load data
-  return(dplyr::collect(arrow::open_dataset(trends_paths)))
+  trends <- NULL
+  for (pq in trends_paths) {
+    trends <- dplyr::bind_rows(trends, arrow::read_parquet(pq))
+  }
+  return(trends)
+}
+
+
+#' Load eBird Status and Trends Data Coverage Products
+#'
+#' The data coverage products are packaged as individual GeoTIFF files for each
+#' product for each week of the year. This function loads one of the available
+#' data products for one or more weeks into R as a
+#' [SpatRaster][terra::SpatRaster] object. Note that data must be downloaded
+#' using [ebirdst_download_data_coverage()] prior to loading it using this
+#' function.
+#'
+#' @param product character; data coverage raster product to load: spatial
+#'   coverage or site selection probability.
+#' @param weeks character; one or more weeks (expressed in `"MM-DD"` format) to
+#'   load the raster layers for. If this argument is not specified, all
+#'   downloaded weeks will be loaded. **Note that these rasters are quite large
+#'   so it's recommended to only load a small number of weeks of data at the
+#'   same time.**
+#' @inheritParams ebirdst_download_status
+#'
+#' @details In addition to the species-specific data products, the eBird Status
+#'   data products include two products providing estimates of weekly data
+#'   coverage at 3 km spatial resolution:
+#'
+#' - `spatial-coverage`: a spatially smoothed estimate of the proportion of the
+#' area that was covered by eBird checklists for the given week.
+#' - `selection-probability`: a modeled estimate of the probability that the
+#' given location and habitat was sampled by eBird data in the given week.
+#'
+#' @return A [SpatRaster][terra::SpatRaster] with between 1 and 52 layers for
+#'   the given product for the given weeks, where the layer names are the dates
+#'   (`YYYY-MM-DD` format) of the midpoint of each week.
+#'
+#' @export
+#'
+#' @examples
+#' \dontrun{
+#' # download example data if hasn't already been downloaded
+#' ebirdst_download_data_coverage()
+#'
+#' # load a single week of site selection probability data
+#' load_data_coverage("selection-probability", weeks = "01-04")
+#'
+#' # load all weeks of spatial coverage data
+#' load_data_coverage("spatial-coverage", weeks = c("01-04", "01-11"))
+#' }
+load_data_coverage <- function(product = c("spatial-coverage",
+                                           "selection-probability"),
+                               weeks = NULL,
+                               path = ebirdst_data_dir()) {
+  product <- match.arg(product)
+  stopifnot(is.character(weeks))
+  stopifnot(dir.exists(path))
+
+  dc_path <- get_species_path("data_coverage", path = path,
+                              dataset = "status",
+                              check_downloaded = FALSE)
+  if (!dir.exists(dc_path)) {
+    stop("No data coverage products were found. Ensure that the data were ",
+         "downloaded using ebirdst_download_data_coverage() and that the ",
+         "'path' argument correctly points to the data download directory.")
+  }
+
+  # check that the geotiff driver is installed
+  drv <- terra::gdal(drivers = TRUE)
+  drv <- drv$name[stringr::str_detect(drv$can, "read")]
+  if (!"GTiff" %in% drv) {
+    stop("GDAL does not have GeoTIFF support. GeoTIFF support is required to ",
+         "load Status and Trends raster data.")
+  }
+
+  # generate vector of valid weeks
+  valid_weeks <- as.Date(paste(2018, seq(4, 366, 7)), format = "%Y %j")
+  valid_weeks <- format(valid_weeks, format = "%m-%d")
+  if (!is.null(weeks) && !all(weeks %in% valid_weeks)) {
+    stop("The following weeks are invalid: ",
+         paste(weeks[!weeks %in% valid_weeks], collapse = ", "), "\n",
+         "Valid weeks include: ", paste(valid_weeks, collapse = ", "))
+  }
+  # subset to selected weeks
+  if (!is.null(weeks)) {
+    valid_weeks <- intersect(valid_weeks, weeks)
+  }
+  valid_weeks <- paste(ebirdst_version()[["status_version_year"]],
+                       valid_weeks, sep = "-")
+
+  # construct filenames
+  product <- paste0(product, "_mean")
+  files <- stringr::str_glue("{product}_{valid_weeks}.tif")
+  files <- file.path(dc_path, product, files)
+
+  # check existence of target files
+  if (!all(file.exists(files))) {
+    missing_files <- files[!file.exists(files)]
+    stop("The files for the requested product do not exist. You may need to ",
+         "download them using ebirdst_download_data_coverage(): \n  ",
+         paste(basename(files), sep = "\n"))
+  }
+
+  # load and return raster stack
+  return(stats::setNames(terra::rast(files), valid_weeks))
 }
 
 
@@ -349,6 +457,7 @@ load_ranges <- function(species,
 
   species_code <- get_species(species)
   species_path <- get_species_path(species, path = path,
+                                   dataset = "status",
                                    check_downloaded = FALSE)
   if (!dir.exists(species_path)) {
     stop("No data found for the requested species. Ensure that the data were ",
@@ -397,6 +506,9 @@ load_ranges <- function(species,
 #'   or other sub-national regions.
 #'   - `region_code`: alphanumeric code for the region.
 #'   - `region_name`: English name of the region.
+#'   - `continent_code`: alphanumeric code for continent that this region
+#'   belongs to.
+#'   - `continent_name`: name of the continent that this region belongs to.
 #'   - `season`: name of the season that the summary statistics were calculated
 #'   for.
 #'   - `abundance_mean`: mean relative abundance in the region.
@@ -423,6 +535,7 @@ load_regional_stats <- function(species, path = ebirdst_data_dir()) {
 
   species_code <- get_species(species)
   species_path <- get_species_path(species, path = path,
+                                   dataset = "status",
                                    check_downloaded = FALSE)
   if (!dir.exists(species_path)) {
     stop("No data found for the requested species. Ensure that the data were ",
@@ -466,6 +579,7 @@ load_config <- function(species, path = ebirdst_data_dir()) {
 
   species_code <- get_species(species)
   species_path <- get_species_path(species, path = path,
+                                   dataset = "status",
                                    check_downloaded = FALSE)
   if (!dir.exists(species_path)) {
     stop("No data found for the requested species. Ensure that the data were ",
@@ -502,7 +616,7 @@ load_config <- function(species, path = ebirdst_data_dir()) {
 #' data for the given species in the custom projection
 #' - `res`: a numeric vector with 2 elements giving the target resolution of
 #'    raster in the custom projection
-#' - `fa_extent_sinu`: the extent in sinusoidal projection
+#' - `fa_extent_projected`: the extent in projected (Equal Earth) coordinates
 #' - `weekly_bins`/`weekly_labels`: weekly abundance bins and labels for the
 #' full annual cycle
 #' - `seasonal_bins`/`seasonal_labels: seasonal abundance bins and labels for
@@ -523,6 +637,7 @@ load_fac_map_parameters <- function(species, path = ebirdst_data_dir()) {
 
   species_code <- get_species(species)
   species_path <- get_species_path(species, path = path,
+                                   dataset = "status",
                                    check_downloaded = FALSE)
   if (!dir.exists(species_path)) {
     stop("No data found for the requested species. Ensure that the data were ",
@@ -532,32 +647,33 @@ load_fac_map_parameters <- function(species, path = ebirdst_data_dir()) {
 
   # load config file
   p <- load_config(species = species_code, path = path)
-  ext_order <- unlist(p$bbox_sinu)[c("xmin", "xmax", "ymin", "ymax")]
+  ext_order <- unlist(p$bbox_native)[c("xmin", "xmax", "ymin", "ymax")]
 
-  seasonal_bins <- list(custom_projection = p$projection$crs,
-                        fa_extent = terra::ext(p$projection$extent),
-                        res = p$projection$res,
-                        fa_extent_sinu = terra::ext(ext_order),
-                        weekly_bins = p$bins[["3km"]]$breaks,
-                        weekly_labels = p$bins[["3km"]]$labels,
-                        seasonal_bins = p$bins_seasonal[["3km"]]$breaks,
-                        seasonal_labels = p$bins_seasonal[["3km"]]$labels)
+  list(custom_projection = p$projection$crs,
+       fa_extent = terra::ext(p$projection$extent),
+       res = p$projection$res,
+       fa_extent_projected = terra::ext(ext_order),
+       weekly_bins = p$bins[["3km"]]$breaks,
+       weekly_labels = p$bins[["3km"]]$labels,
+       seasonal_bins = p$bins_seasonal[["3km"]]$breaks,
+       seasonal_labels = p$bins_seasonal[["3km"]]$labels)
 }
 
 
 #' Load predictor importance (PI) rasters
 #'
-#' The eBird Status models estimate the relative importance of each
-#' environmental predictor used in the model. These predictor importance (PI)
-#' data are converted to ranks (with a rank of 1 being the most important)
-#' relative to the full suite of environmental predictors. The ranks are
-#' summarized to a 27 km resolution raster grid for each predictor, where the
-#' cell values are the average across all models in the ensemble contributing to
-#' that cell. These data are available in raster format provided `download_pis =
-#' TRUE` was used when calling [ebirdst_download_status()]. PI estimates are
-#' available separately for both the occurrence and count sub-model and only the
-#' 30 most important predictors are distributed. Use [list_available_pis()] to
-#' see which predictors have PI data.
+#' The eBird Status models estimate the relative importance of each of the core
+#' environmental predictor used in the model (i.e. the % land and water cover
+#' variables). These predictor importance (PI) data are converted to ranks (with
+#' a rank of 1 being the most important) relative to the full suite of
+#' environmental predictors. The ranks are summarized to a 27 km resolution
+#' raster grid for each predictor, where the cell values are the average across
+#' all models in the ensemble contributing to that cell. These data are
+#' available in raster format provided `download_pis = TRUE` was used when
+#' calling [ebirdst_download_status()]. PI estimates are available separately
+#' for both the occurrence and count sub-model and only the 30 most important
+#' predictors are distributed. Use [list_available_pis()] to see which
+#' predictors have PI data.
 #'
 #' @inheritParams load_raster
 #' @param predictor character; the predictor that the PI data should be loaded
@@ -574,8 +690,8 @@ load_fac_map_parameters <- function(species, path = ebirdst_data_dir()) {
 #'
 #' [list_available_pis()] returns a data frame listing the top 30 predictors for
 #' which PI rasters can be loaded. In addition to the predictor names, the mean
-#' range-wide rank (`rangewide_rank`) is given as well as the integer rank
-#' (`rank`) relative to the other 29 predictors.
+#' range-wide rank (`rank_mean`) is given as well as the integer rank
+#' (`rank`) relative to the full suite of predictors (environmental and effort).
 #'
 #' @export
 #'
@@ -598,6 +714,7 @@ load_pi <- function(species, predictor, response = c("occurrence", "count"),
 
   species_code <- get_species(species)
   species_path <- get_species_path(species, path = path,
+                                   dataset = "status",
                                    check_downloaded = FALSE)
   if (!dir.exists(species_path)) {
     stop("No data found for the requested species. Ensure that the data were ",
@@ -634,7 +751,7 @@ list_available_pis <- function(species, path = ebirdst_data_dir()) {
          "argument correctly points to the data download directory.")
   }
 
-  csv_file <- file.path(species_path, "pis", "pi_rangewide-ranks.csv")
+  csv_file <- file.path(species_path, "pis", "pi_rangewide.csv")
   if(!file.exists(csv_file)) {
     stop("The PI data could not be found. To download, use ",
          "`ebirst_download_status(download_pis = TRUE)`.")
@@ -652,7 +769,7 @@ list_available_pis <- function(species, path = ebirdst_data_dir()) {
 
   # return ranks
   top_ranks <- dplyr::as_tibble(ranks[ranks$predictor %in% preds, ])
-  top_ranks <- dplyr::arrange(top_ranks, .data$rank)
+  top_ranks <- dplyr::arrange(top_ranks, .data$response, .data$rank)
 
   return(top_ranks)
 }
@@ -673,28 +790,61 @@ list_available_pis <- function(species, path = ebirdst_data_dir()) {
 #'   Details for definitions of each metric.
 #'
 #' @details
-#' Eight predictive performance metrics are provided:
+#' Nineteen predictive performance metrics are provided:
 #' - `binary_f1`: F1-score comparing the model predictions converted to binary
 #' with the observed detection/non-detection for the test checklists.
-#' - `binary_pr_auc`: the area on the precision-recall curve generated by
-#' comparing the model predictions converted to binary with the observed
-#' detection/non-detection for the test checklists.
-#' - `occ_bernoulli_dev`: Bernoulli deviance comparing the predicted occurrence
-#' with the observed detection/non-detection for the test checklists.
-#' - `count_spearman`: Spearman's rank correlation coefficient comparing the
-#' predicted count with the observed count for the subset of test checklists
-#' on which the species was detected.
-#' - `log_count_pearson`: Pearson correlation coefficient comparing the
-#' logarithm of the predicted count with the logarithm of the observed count
-#' for the subset of test checklists on which the species was detected.
-#' - `abd_poisson_dev`: Poisson deviance comparing the predicted relative
-#' abundance with the observed count for the full set of test checklists.
-#' - `abd_spearman`: Spearman's rank  correlation coefficient comparing the
-#' predicted relative abundance with the observed count for the full set of
+#' - `binary_mcc`: Matthews Correlation Coefficient (MCC) comparing the model
+#' predictions converted to binary with the observed detection/non-detection
+#' for the test checklists.
+#' - `binary_prevalence`: the observed detection probability after
+#' spatiotemporal subsampling.
+#' - `occ_bernoulli_dev`: proportion of Bernoulli deviance explained comparing
+#' the predicted occurrence with the observed detection/non-detection for the
 #' test checklists.
-#' - `log_abd_pearson`: Pearson correlation coefficient comparing the logarithm
+#' - `occ_bin_spearman`: test observations are binned by predicted encounter
+#' rate with bin widths of 0.05, then the mean observed prevalence and predicted
+#' encounter rate are calculated within bins. This metric is the Spearman's rank
+#' correlation coefficient comparing the observed and predicted binned mean
+#' values.
+#' - `occ_brier`: the Brier score is the mean squared difference between
+#' predicted encounter rate and observed detection/non-detection.
+#' - `occ_pr_auc`: the area on the precision-recall curve (PR AUC) generated by
+#' comparing the predicted encounter rate with the observed
+#' detection/non-detection for the test checklists.
+#' - `occ_pr_auc_gt_prev`: the proportion of the ensemble for which the PR AUC
+#' is greater than observed prevalence, which indicates that the model is
+#' performing better than random guessing.
+#' - `occ_pr_auc_normalized`: the PR AUC normalized to account for class
+#' imbalance so that a value of 0 represents performance equal to random
+#' guessing and a value of 1 represents perfect classification.
+#' - `count_log_pearson`: Pearson correlation coefficient comparing the
+#' logarithm of the predicted count with the logarithm of the observed count for
+#' the subset of test checklists on which the species was detected.
+#' - `count_mae`: the mean absolute error (MAE) comparing the observed and
+#' predicted counts for the subset of test checklists on which the species was
+#' detected.
+#' - `count_poisson_dev`: proportion of Poisson deviance explained, comparing
+#' the observed and predicted counts for the subset of test checklists on which
+#' the species was detected.
+#' - `count_rmse`: route mean squared error (RMSE) comparing the observed and
+#' predicted counts for the subset of test checklists on which the species was
+#' detected.
+#' - `count_spearman`: Spearman's rank correlation coefficient comparing the
+#' observed and predicted counts for the subset of test checklists on which the
+#' species was detected.
+#' - `abd_log_pearson`: Pearson correlation coefficient comparing the logarithm
 #' of the predicted relative abundance with the logarithm of the observed
 #' count for the full set of test checklists.
+#' - `abd_mae`: the mean absolute error (MAE) comparing the observed counts and
+#' predicted relative abundance for the full set of test checklists.
+#' - `abd_poisson_dev`: proportion of Poisson deviance explained, comparing the
+#' predicted relative abundance with the observed count for the full set of test
+#' checklists.
+#' - `abd_rmse`: root mean squared error comparing the predicted relative
+#' abundance with the observed count for the full set of test checklists.
+#' - `abd_spearman`: Spearman's rank correlation coefficient comparing the
+#' predicted relative abundance with the observed count for the full set of
+#' test checklists.
 #'
 #' @return A [SpatRaster][terra::SpatRaster] object with the PPM data. For
 #'   migrants, rasters are weekly with  52 layers, where the layer names are the
@@ -713,19 +863,31 @@ list_available_pis <- function(species, path = ebirdst_data_dir()) {
 #' }
 load_ppm <- function(species,
                      ppm = c("binary_f1",
-                             "binary_pr_auc",
+                             "binary_mcc",
+                             "binary_prevalence",
                              "occ_bernoulli_dev",
+                             "occ_bin_spearman",
+                             "occ_brier",
+                             "occ_pr_auc",
+                             "occ_pr_auc_gt_prev",
+                             "occ_pr_auc_normalized",
+                             "count_log_pearson",
+                             "count_mae",
+                             "count_poisson_dev",
+                             "count_rmse",
                              "count_spearman",
-                             "log_count_pearson",
+                             "abd_log_pearson",
+                             "abd_mae",
                              "abd_poisson_dev",
-                             "abd_spearman",
-                             "log_abd_pearson"),
+                             "abd_rmse",
+                             "abd_spearman"),
                      path = ebirdst_data_dir()) {
   stopifnot(is.character(species), length(species) == 1, dir.exists(path))
   ppm <- match.arg(ppm)
 
   species_code <- get_species(species)
   species_path <- get_species_path(species, path = path,
+                                   dataset = "status",
                                    check_downloaded = FALSE)
   if (!dir.exists(species_path)) {
     stop("No data found for the requested species. Ensure that the data were ",
@@ -736,7 +898,7 @@ load_ppm <- function(species,
   # construct file name
   year <- load_config(species = species, path = path)[["srd_pred_year"]]
   p <- stringr::str_replace_all(ppm, "_", "-")
-  tif <- stringr::str_glue("{species_code}_ppm_{p}_27km_{year}.tif")
+  tif <- stringr::str_glue("{species_code}_ppm_{p}_mean_27km_{year}.tif")
   tif <- file.path(species_path, "ppms", tif)
   if (!file.exists(tif)) {
     stop("GeoTIFF for ", ppm, " PPM could not be found. To download ",
