@@ -15,7 +15,8 @@ test_that("load_config()", {
 test_that("load_fac_map_parameters()", {
   p <- load_fac_map_parameters("yebsap-example")
   expect_is(p, "list")
-  expect_named(p, c("custom_projection", "fa_extent", "res", "fa_extent_sinu",
+  expect_named(p, c("custom_projection", "fa_extent",
+                    "res", "fa_extent_projected",
                     "weekly_bins", "weekly_labels",
                     "seasonal_bins", "seasonal_labels"))
 
@@ -26,8 +27,8 @@ test_that("load_fac_map_parameters()", {
   expect_is(p$fa_extent, "SpatExtent")
   # resolution
   expect_is(p$res, c("numeric", "integer"))
-  # sinusoidal extent
-  expect_is(p$fa_extent_sinu, "SpatExtent")
+  # projected extent
+  expect_is(p$fa_extent_projected, "SpatExtent")
   # bins
   expect_is(p$weekly_bins, "numeric")
   expect_is(p$seasonal_bins, "numeric")
@@ -40,8 +41,8 @@ test_that("load_fac_map_parameters()", {
 test_that("list_available_pis()", {
   pis <- list_available_pis("yebsap-example")
   expect_is(pis, "data.frame")
-  expect_true(all(c("predictor", "rangewide_rank", "rank") %in% names(pis)))
-  expect_equal(nrow(pis), 5)
+  expect_true(all(c("predictor", "rank_mean", "rank") %in% names(pis)))
+  expect_equal(nrow(pis), 10)
 
   expect_error(list_available_pis("Yellow Warbler"))
   expect_error(list_available_pis("XXXX"))
@@ -50,13 +51,13 @@ test_that("list_available_pis()", {
 
 test_that("load_pi()", {
   pi_occ <- load_pi("yebsap-example",
-                    predictor = "elevation_250m_median",
+                    predictor = "gsw_c2_pland",
                     response = "occurrence")
   expect_is(pi_occ, "SpatRaster")
   expect_equal(terra::nlyr(pi_occ), 52)
 
   pi_count <- load_pi("yebsap-example",
-                      predictor = "mcd12q1_lccs1_c22_pland",
+                      predictor = "mcd12q1_lccs1_c21_pland",
                       response = "count")
   expect_is(pi_count, "SpatRaster")
   expect_equal(terra::nlyr(pi_count), 52)
@@ -69,13 +70,13 @@ test_that("load_pi()", {
 
 
 test_that("load_ppm()", {
-  ppm_spear <- load_ppm("yebsap-example", ppm = "abd_spearman")
-  expect_is(ppm_spear, "SpatRaster")
-  expect_equal(terra::nlyr(ppm_spear), 52)
+  ppm_pois <- load_ppm("yebsap-example", ppm = "abd_poisson_dev")
+  expect_is(ppm_pois, "SpatRaster")
+  expect_equal(terra::nlyr(ppm_pois), 52)
 
-  ppm_auc <- load_ppm("yebsap-example", ppm = "binary_pr_auc")
-  expect_is(ppm_auc, "SpatRaster")
-  expect_equal(terra::nlyr(ppm_auc), 52)
+  ppm_fs <- load_ppm("yebsap-example", ppm = "binary_f1")
+  expect_is(ppm_fs, "SpatRaster")
+  expect_equal(terra::nlyr(ppm_fs), 52)
 
   expect_error(load_ppm("Yellow Warbler"))
   expect_error(load_ppm("XXXX"))
